print("import: 'google.api'")
import google.api

print("import: 'google.iam'")
import google.iam

print("import: 'google.iam.v1'")
import google.iam.v1

print("import: 'google.iam.v1.iam_policy_pb2'")
import google.iam.v1.iam_policy_pb2

print("import: 'google.iam.v1.logging'")
import google.iam.v1.logging

print("import: 'google.iam.v1.logging.audit_data_pb2'")
import google.iam.v1.logging.audit_data_pb2

print("import: 'google.iam.v1.policy_pb2'")
import google.iam.v1.policy_pb2

print("import: 'google.protobuf'")
import google.protobuf

print("import: 'google.rpc'")
import google.rpc

print("import: 'google.rpc.code_pb2'")
import google.rpc.code_pb2

print("import: 'google.rpc.error_details_pb2'")
import google.rpc.error_details_pb2

print("import: 'google.rpc.status_pb2'")
import google.rpc.status_pb2

print("import: 'grpc'")
import grpc

